@@ -10,7 +10,7 @@ exit;
 ; Project   : NagiosQL
 ; Component : Initial configuration settings
 ; Website   : https://sourceforge.net/projects/nagiosql/
-; Version   : 3.4.0
+; Version   : 3.5.0
 ; GIT Repo  : https://gitlab.com/wizonet/NagiosQL
 ;
 ; DO NOT USE THIS FILE AS NAGIOSQL SETTINGS FILE!
@@ -20,7 +20,7 @@ exit;
 type            = mysqli
 server          = localhost
 port            = 3306
-database        = db_nagiosql_v34
+database        = db_nagiosql_v35
 username        = nagiosql_user
 password        = nagiosql_pass
 [path]
@@ -44,4 +44,6 @@ proxy           = 0
 proxyserver     = ''
 proxyuser       = ''
 proxypasswd     = ''
-onlineupdate    = 0
\ No newline at end of file
+onlineupdate    = 0
+[performance]
+parents         = 1
\ No newline at end of file
